@@ -2,7 +2,12 @@
 from typing import List, Optional
 
 from ..strategy import AwesomeVersionStrategy
-from ..utils.regex import RE_MODIFIER, RE_SEMVER, get_regex_match_group
+from ..utils.regex import (
+    RE_MODIFIER,
+    RE_SEMVER,
+    generate_full_string_regex,
+    get_regex_match_group,
+)
 from .sections import ComparelHandlerSections
 
 SEMVER_MODIFIER_MAP = {"alpha": 1, "beta": 2, "rc": 3}
@@ -31,12 +36,16 @@ class ComparelHandlerSemVerModifier(ComparelHandlerSections):
 
                 ver_a_modifier = get_regex_match_group(
                     RE_MODIFIER,
-                    get_regex_match_group(RE_SEMVER, self.ver_a.string, 4),
+                    get_regex_match_group(
+                        generate_full_string_regex(RE_SEMVER), self.ver_a.string, 4
+                    ),
                     4,
                 )
                 ver_b_modifier = get_regex_match_group(
                     RE_MODIFIER,
-                    get_regex_match_group(RE_SEMVER, self.ver_b.string, 4),
+                    get_regex_match_group(
+                        generate_full_string_regex(RE_SEMVER), self.ver_b.string, 4
+                    ),
                     4,
                 )
                 if not ver_a_modifier:
